function [regions] = algorithm_heuristic(im,image_meta,varargin)

overlap = 15; %percent
n_tile_row = 3;
n_tile_col = 3;

if (~isempty(varargin))
    if (~isempty(varargin{1}))
        n_tile_row = varargin{1}.n_tile_row;    
        n_tile_col = varargin{1}.n_tile_col;
    end
end

tile_overlap = 0.1;

tile3x6_filename = '../calibration/40x_1x1_info.txt';
tile3x6 = read_metadata(tile3x6_filename,[]);
tile_length = [0 0 tile3x6.absolute_length];

tile_length(3) = n_tile_row * tile_length(3) - ( (n_tile_row-1) * tile_overlap);
tile_length(4) = n_tile_col * tile_length(4) - ( (n_tile_col -1) * tile_overlap);

tile_length_pixels = absolute2pixels(tile_length,image_meta);

[blobs,im_labels] = find_specimens(im);

[max_row, max_col,~] = size(im);

regions = [];

im_labels_selected = zeros(size(im_labels,1),size(im_labels,2));

for x_blob = 1:length(blobs)
    im_labels_selected(im_labels == blobs(x_blob).id) = 1;
end

im_integral = integral_image(im_labels_selected);

x_region = 1;
for x_blob = 1:length(blobs)
    blob_region_pixels = (blobs(x_blob).bbox);
%     col_start = blob_region_pixels(1);
%     row_start = blob_region_pixels(2);
%     
%     col_end = blob_region_pixels(3);
%     row_end = blob_region_pixels(4);
                
    col_step = floor((100-overlap) / 100 * tile_length_pixels(3));
    row_step = floor((100-overlap) / 100 * tile_length_pixels(4));
    col_end = blob_region_pixels(1)+blob_region_pixels(3);
    row_end = blob_region_pixels(2)+blob_region_pixels(4);
    
    if (col_end + tile_length_pixels(3) > max_col)
        col_end = max_col - tile_length_pixels(3);
    end
    if (row_end + tile_length_pixels(4) > max_row)
        row_end = max_row - tile_length_pixels(4);
    end
    
    for col_start = blob_region_pixels(1):col_step:col_end
        for row_start = blob_region_pixels(2):row_step:row_end
            region_tmp = [col_start row_start tile_length_pixels(3:4)];
            if (isspecimen(im_integral,region_tmp) == 1)
                regions(x_region,:) = pixels2absolute(region_tmp,image_meta);
                x_region = x_region + 1;
            end
        end
    end
        
    
end


function [r] = isspecimen(im_integral,bbox)

threshold = 40; %percent
total_size = bbox(3) * bbox(4);

actual_size = compute_sum(im_integral,bbox(2),bbox(1),bbox(2)+bbox(4),bbox(1)+bbox(3));

percent = actual_size / total_size * 100;
if (percent > threshold)
    r = 1;
else
    r = 0;
end